predict.mactivate_fit_hybrid_01: Predict from Fitted Hybrid Model
Usage
# S3 method for mactivate_fit_hybrid_01
predict(object, X0, U0=NULL, mcols, ...)
Arguments
X0
Numeric matrix, N x d. Model `primary effect' inputs.
U0
Numeric matrix with N rows. Inputs to pass to activation layer.
mcols
Scalar non-negative integer specifying which first columns of W to use.
…
Nothing else is required for this extension of the predict() function.
Value
yhat. Numeric vector of length N.
Details
If U0 is not provided, X0 will be passed to activation layer.
Examples
Run this code# NOT RUN {
####### Please see examples in the fitting functions
# }
Run the code above in your browser using DataLab